@@ -15,6 +15,12 @@ namespace OCA\News\Db;
 
 use OCP\AppFramework\Db\Entity;
 
+/**
+ * Class Item
+ *
+ * @package OCA\News\Db
+ * @Embeddable
+ */
 class Item extends Entity implements IAPI, \JsonSerializable
 {
     use EntityJSONSerializer;
@@ -97,7 +103,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $item;
     }
 
-    public function generateSearchIndex()
+    public function generateSearchIndex(): void
     {
         $this->setSearchIndex(
             mb_strtolower(
@@ -115,7 +121,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getAuthor()
+    public function getAuthor(): ?string
     {
         return $this->author;
     }
@@ -123,7 +129,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getBody()
+    public function getBody(): ?string
     {
         return $this->body;
     }
@@ -131,7 +137,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getContentHash()
+    public function getContentHash(): ?string
     {
         return $this->contentHash;
     }
@@ -139,7 +145,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getEnclosureLink()
+    public function getEnclosureLink(): ?string
     {
         return $this->enclosureLink;
     }
@@ -147,7 +153,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getMediaThumbnail()
+    public function getMediaThumbnail(): ?string
     {
         return $this->mediaThumbnail;
     }
@@ -155,7 +161,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getMediaDescription()
+    public function getMediaDescription(): ?string
     {
         return $this->mediaDescription;
     }
@@ -163,12 +169,12 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getEnclosureMime()
+    public function getEnclosureMime(): ?string
     {
         return $this->enclosureMime;
     }
 
-    public function getFeedId()
+    public function getFeedId(): string
     {
         return $this->feedId;
     }
@@ -176,7 +182,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getFingerprint()
+    public function getFingerprint(): ?string
     {
         return $this->fingerprint;
     }
@@ -191,12 +197,12 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this->guidHash;
     }
 
-    public function getId()
+    public function getId(): string
     {
         return $this->id;
     }
 
-    public function getIntro()
+    public function getIntro(): string
     {
         return strip_tags($this->getBody());
     }
@@ -204,7 +210,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return string|null
      */
-    public function getLastModified()
+    public function getLastModified(): ?string
     {
         return $this->lastModified;
     }
@@ -212,7 +218,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return int|null
      */
-    public function getPubDate()
+    public function getPubDate(): ?int
     {
         return $this->pubDate;
     }
@@ -225,7 +231,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getSearchIndex()
+    public function getSearchIndex(): ?string
     {
         return $this->searchIndex;
     }
@@ -233,7 +239,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getTitle()
+    public function getTitle(): ?string
     {
         return $this->title;
     }
@@ -241,7 +247,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return int|null
      */
-    public function getUpdatedDate()
+    public function getUpdatedDate(): ?int
     {
         return $this->updatedDate;
     }
@@ -249,17 +255,17 @@ class Item extends Entity implements IAPI, \JsonSerializable
     /**
      * @return null|string
      */
-    public function getUrl()
+    public function getUrl(): ?string
     {
         return $this->url;
     }
 
-    public function isStarred()
+    public function isStarred(): bool
     {
         return $this->starred;
     }
 
-    public function isUnread()
+    public function isUnread(): bool
     {
         return $this->unread;
     }
@@ -293,7 +299,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
         ];
     }
 
-    public function setAuthor(string $author = null)
+    public function setAuthor(string $author = null): self
     {
         $author = strip_tags($author);
 
@@ -301,9 +307,11 @@ class Item extends Entity implements IAPI, \JsonSerializable
             $this->author = $author;
             $this->markFieldUpdated('author');
         }
+
+        return $this;
     }
 
-    public function setBody(string $body = null)
+    public function setBody(string $body = null): self
     {
         // FIXME: this should not happen if the target="_blank" is already
         // on the link
@@ -313,129 +321,161 @@ class Item extends Entity implements IAPI, \JsonSerializable
             $this->body = $body;
             $this->markFieldUpdated('body');
         }
+
+        return $this;
     }
 
-    public function setContentHash(string $contentHash = null)
+    public function setContentHash(string $contentHash = null): self
     {
         if ($this->contentHash !== $contentHash) {
             $this->contentHash = $contentHash;
             $this->markFieldUpdated('contentHash');
         }
+
+        return $this;
     }
 
-    public function setEnclosureLink(string $enclosureLink = null)
+    public function setEnclosureLink(string $enclosureLink = null): self
     {
         if ($this->enclosureLink !== $enclosureLink) {
             $this->enclosureLink = $enclosureLink;
             $this->markFieldUpdated('enclosureLink');
         }
+
+        return $this;
     }
 
-    public function setEnclosureMime(string $enclosureMime = null)
+    public function setEnclosureMime(string $enclosureMime = null): self
     {
         if ($this->enclosureMime !== $enclosureMime) {
             $this->enclosureMime = $enclosureMime;
             $this->markFieldUpdated('enclosureMime');
         }
+
+        return $this;
     }
 
-    public function setMediaThumbnail(string $mediaThumbnail = null)
+    public function setMediaThumbnail(string $mediaThumbnail = null): self
     {
         if ($this->mediaThumbnail !== $mediaThumbnail) {
             $this->mediaThumbnail = $mediaThumbnail;
             $this->markFieldUpdated('mediaThumbnail');
         }
+
+        return $this;
     }
 
-    public function setMediaDescription(string $mediaDescription = null)
+    public function setMediaDescription(string $mediaDescription = null): self
     {
         if ($this->mediaDescription !== $mediaDescription) {
             $this->mediaDescription = $mediaDescription;
             $this->markFieldUpdated('mediaDescription');
         }
+
+        return $this;
     }
 
-    public function setFeedId(int $feedId)
+    public function setFeedId(int $feedId): self
     {
         if ($this->feedId !== $feedId) {
             $this->feedId = $feedId;
             $this->markFieldUpdated('feedId');
         }
+
+        return $this;
     }
 
-    public function setFingerprint(string $fingerprint = null)
+    public function setFingerprint(string $fingerprint = null): self
     {
         if ($this->fingerprint !== $fingerprint) {
             $this->fingerprint = $fingerprint;
             $this->markFieldUpdated('fingerprint');
         }
+
+        return $this;
     }
 
-    public function setGuid(string $guid)
+    public function setGuid(string $guid): self
     {
         if ($this->guid !== $guid) {
             $this->guid = $guid;
             $this->markFieldUpdated('guid');
         }
+
+        return $this;
     }
 
-    public function setGuidHash(string $guidHash)
+    public function setGuidHash(string $guidHash): self
     {
         if ($this->guidHash !== $guidHash) {
             $this->guidHash = $guidHash;
             $this->markFieldUpdated('guidHash');
         }
+
+        return $this;
     }
 
-    public function setId(int $id)
+    public function setId(int $id): self
     {
         if ($this->id !== $id) {
             $this->id = $id;
             $this->markFieldUpdated('id');
         }
+
+        return $this;
     }
 
-    public function setLastModified(string $lastModified = null)
+    public function setLastModified(string $lastModified = null): self
     {
         if ($this->lastModified !== $lastModified) {
             $this->lastModified = $lastModified;
             $this->markFieldUpdated('lastModified');
         }
+
+        return $this;
     }
 
-    public function setPubDate(int $pubDate = null)
+    public function setPubDate(int $pubDate = null): self
     {
         if ($this->pubDate !== $pubDate) {
             $this->pubDate = $pubDate;
             $this->markFieldUpdated('pubDate');
         }
+
+        return $this;
     }
 
-    public function setRtl(bool $rtl)
+    public function setRtl(bool $rtl): self
     {
         if ($this->rtl !== $rtl) {
             $this->rtl = $rtl;
             $this->markFieldUpdated('rtl');
         }
+
+        return $this;
     }
 
-    public function setSearchIndex(string $searchIndex = null)
+    public function setSearchIndex(string $searchIndex = null): self
     {
         if ($this->searchIndex !== $searchIndex) {
             $this->searchIndex = $searchIndex;
             $this->markFieldUpdated('searchIndex');
         }
+
+        return $this;
     }
 
-    public function setStarred(bool $starred)
+    public function setStarred(bool $starred): self
     {
         if ($this->starred !== $starred) {
             $this->starred = $starred;
             $this->markFieldUpdated('starred');
         }
+
+        return $this;
     }
 
-    public function setTitle(string $title = null)
+    public function setTitle(string $title = null): self
     {
         $title = strip_tags($title);
 
@@ -443,25 +483,31 @@ class Item extends Entity implements IAPI, \JsonSerializable
             $this->title = $title;
             $this->markFieldUpdated('title');
         }
+
+        return $this;
     }
 
-    public function setUnread(bool $unread)
+    public function setUnread(bool $unread): self
     {
         if ($this->unread !== $unread) {
             $this->unread = $unread;
             $this->markFieldUpdated('unread');
         }
+
+        return $this;
     }
 
-    public function setUpdatedDate(int $updatedDate = null)
+    public function setUpdatedDate(int $updatedDate = null): self
     {
         if ($this->updatedDate !== $updatedDate) {
             $this->updatedDate = $updatedDate;
             $this->markFieldUpdated('updatedDate');
         }
+
+        return $this;
     }
 
-    public function setUrl(string $url = null)
+    public function setUrl(string $url = null): self
     {
         $url = trim($url);
         if ((strpos($url, 'http') === 0 || strpos($url, 'magnet') === 0)
@@ -470,6 +516,8 @@ class Item extends Entity implements IAPI, \JsonSerializable
             $this->url = $url;
             $this->markFieldUpdated('url');
         }
+
+        return $this;
     }
 
     public function toAPI(): array
@@ -543,7 +591,7 @@ class Item extends Entity implements IAPI, \JsonSerializable
      *
      * @return boolean
      */
-    public function isSupportedMime($mime)
+    public function isSupportedMime(string $mime): bool
     {
         return (
             stripos($mime, 'audio/') !== false ||
